summaryrefslogtreecommitdiff
path: root/interface/OptionInterface.h
diff options
context:
space:
mode:
Diffstat (limited to 'interface/OptionInterface.h')
-rw-r--r--interface/OptionInterface.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/interface/OptionInterface.h b/interface/OptionInterface.h
index 9638170..034b49d 100644
--- a/interface/OptionInterface.h
+++ b/interface/OptionInterface.h
@@ -6,10 +6,10 @@
#ifndef OPTION_INTERFACE_H
#define OPTION_INTERFACE_H
-#include <QString>
-#include <QList>
-#include <QVariant>
-#include <QPair>
+#include <string>
+#include <vector>
+#include <utility>
+#include <QObject>
#include "../StructEnumDefinition.h"
@@ -21,15 +21,15 @@ class OptionInterface : public QObject
Q_OBJECT
public:
/// \brief To add option group to options
- virtual bool addOptionGroup(const QList<QPair<QString, QVariant> > &KeysList) = 0;
+ virtual bool addOptionGroup(const std::vector<std::pair<std::string, std::string> > &KeysList) = 0;
/*/// \brief To remove option group to options, removed to the load plugin
virtual bool removeOptionGroup() = 0;*/
/// \brief To get option value
- virtual QVariant getOptionValue(const QString &variableName) const = 0;
+ virtual std::string getOptionValue(const std::string &variableName) const = 0;
/// \brief To set option value
- virtual void setOptionValue(const QString &variableName,const QVariant &value) = 0;
+ virtual void setOptionValue(const std::string &variableName,const std::string &value) = 0;
signals:
//void newOptionValue(QString,QVariant);-> disabled because the value will not externally changed, then useless notification
void resetOptions() const;
};
@@ -21,15 +21,15 @@ class OptionInterface : public QObject
signals:
- //void newOptionValue(QString,QVariant);-> disabled because the value will not externally changed, then useless notification
+ //void newOptionValue(std::string,std::string);-> disabled because the value will not externally changed, then useless notification
void resetOptions() const;
};